@@ -1,12 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.0991';
+our $VERSION = '1.10';
+# 1.10 added approve and ignore reports functions
 # 1.0991: there was a debug message and get_permalink was broken  
-# 1.099:
-#  -updated get_user and list_subreddits to use set_listing_defaults
-#  -get_user can now accept the 'about' view
-#  -added 'about' user contant
-#  -added "delete" method to Link, which documentation already said was there
 
 $VERSION = eval $VERSION;
 
@@ -109,6 +105,8 @@ use constant API_SEARCH              => 31;
 use constant API_MODQ                => 32;
 use constant API_EDIT                => 33;
 use constant API_REMOVE              => 34;
+use constant API_APPROVE             => 35;
+use constant API_IGNORE_REPORTS      => 36;
 
 #===============================================================================
 # Parameters
@@ -157,6 +155,8 @@ $API[API_SEARCH        ] = ['GET',  '/r/%s/search'            ];
 $API[API_MODQ          ] = ['GET',  '/r/%s/about/%s'          ];
 $API[API_EDIT          ] = ['POST', '/api/editusertext'       ];
 $API[API_REMOVE        ] = ['POST', '/api/remove'             ];
+$API[API_APPROVE       ] = ['POST', '/api/approve'            ];
+$API[API_IGNORE_REPORTS] = ['POST', '/api/ignore_reports'     ];
 #===============================================================================
 # Package routines
 #===============================================================================
@@ -658,6 +658,26 @@ sub remove {
 	);
 	return $result;
 }
+sub approve {
+	my $self = shift;
+	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	
+    	my $result = $self->api_json_request(
+		api  => API_APPROVE,
+		data => { id => $fullname },
+	);
+	return $result;
+}
+sub ignore_reports {
+	my $self = shift;
+	my $fullname = shift || croak "arg 1 (fullname) is required.";
+	
+    	my $result = $self->api_json_request(
+		api  => API_IGNORE_REPORTS,
+		data => { id => $fullname },
+	);
+	return $result;
+}
 # reports spam modqueue unmoderated edited
 sub get_modlinks {
     	my ($self, %param) = @_;
