@@ -22,6 +22,7 @@ use fields (
     'token',
     'tokentype',
 	'request_errors',
+	'print_response',
 );
 
 sub new {
@@ -35,7 +36,8 @@ sub new {
     $self->{modhash}    = $param{modhash};
     $self->{token}	= $param{token};
     $self->{tokentype}	= $param{tokentype};
-	$self->{request_errors}= $param{request_errors} || 0;
+    $self->{request_errors} = $param{request_errors} || 0;
+    $self->{print_response} = $param{print_response} || 0;
 
     if (defined $self->{query}) {
         ref $self->{query} eq 'HASH' || croak 'Expected HASH ref for "query"';
@@ -100,6 +102,7 @@ sub send {
     my $res = $ua->request($request);
 
     if ($res->is_success) {
+	print $res->content . "\n" if $self->{print_response};
         return $res->content;
     } else {
 	if ($self->{request_errors}) {
